import type {BatchWriteItemCommandInput} from '@aws-sdk/client-dynamodb'
import {marshall} from '@aws-sdk/util-dynamodb'
import type {DDBReadOnlyClientConfiguration} from '../DDBReadOnlyClient'

export const mapCreateItemsCommand = <
  Item extends object,
  PKName extends keyof Item,
  SKName extends keyof Item | never = never,
>(
  config: DDBReadOnlyClientConfiguration<Item, PKName, SKName>,
  items: Item[],
): BatchWriteItemCommandInput => {
  return {
    RequestItems: {
      [config.tableName]: items.map((item) => {
        if (!item[config.partitionKeyName]) throw new Error(`Missing partitionKey.`)
        if (config.sortKeyName && !item[config.sortKeyName]) throw new Error(`Missing sortKey.`)
        return {
          PutRequest: {
            Item: marshall(item),
          },
        }
      }),
    },
  }
}
