import type {BatchWriteItemCommandInput} from '@aws-sdk/client-dynamodb'
import type {DDBReadOnlyClientConfiguration} from '../DDBReadOnlyClient'
import {mapKey} from './mapKey'

export const mapDeleteItemsCommand = <
  Item extends object,
  PKName extends keyof Item,
  SKName extends keyof Item | never = never,
>(
  config: DDBReadOnlyClientConfiguration<Item, PKName, SKName>,
  items: (Record<PKName, Item[PKName]> & Record<SKName, Item[SKName]>)[],
): BatchWriteItemCommandInput => {
  return {
    RequestItems: {
      [config.tableName]: items.map((item) => ({
        DeleteRequest: {
          Key: mapKey(config, item[config.partitionKeyName], config.sortKeyName && item[config.sortKeyName]),
        },
      })),
    },
  }
}
